@@ -22,15 +22,6 @@ the address of your emulator should be enough to do the trick.
 [smoke-tests]:
 https://github.com/talkiq/gcloud-rest/tree/master/taskqueue/tests/integration
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-import warnings
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
-    from future import standard_library
-standard_library.install_aliases()
 from pkg_resources import get_distribution
 __version__ = get_distribution('gcloud-rest-taskqueue').version
 
