@@ -1,16 +1,6 @@
 """
 An asynchronous push queue for Google Appengine Task Queues
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-import warnings
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
-    from future import standard_library
-standard_library.install_aliases()
-from builtins import object
 import json
 import logging
 import os
@@ -39,31 +29,31 @@ SCOPES = [
 log = logging.getLogger(__name__)
 
 
-def init_api_root(api_root               )                    :
+def init_api_root(api_root: Optional[str]) -> Tuple[bool, str]:
     if api_root:
         return True, api_root
 
     host = os.environ.get('CLOUDTASKS_EMULATOR_HOST')
     if host:
-        return True, 'http://{}/v2beta3'.format((host))
+        return True, f'http://{host}/v2beta3'
 
     return False, 'https://cloudtasks.googleapis.com/v2beta3'
 
 
-class PushQueue(object):
-    #_api_root: str
-    #_api_is_dev: bool
-    #_queue_path: str
+class PushQueue:
+    _api_root: str
+    _api_is_dev: bool
+    _queue_path: str
 
     def __init__(
-            self, project     , taskqueue     , location      = 'us-central1',
-            service_file                                   = None,
-            session                    = None, token                  = None,
-            api_root                = None,
-    )        :
+            self, project: str, taskqueue: str, location: str = 'us-central1',
+            service_file: Optional[Union[str, IO[AnyStr]]] = None,
+            session: Optional[Session] = None, token: Optional[Token] = None,
+            api_root: Optional[str] = None,
+    ) -> None:
         self._api_is_dev, self._api_root = init_api_root(api_root)
         self._queue_path = (
-            'projects/{}/locations/{}/queues/{}'.format((project), (location), (taskqueue))
+            f'projects/{project}/locations/{location}/queues/{taskqueue}'
         )
 
         self.session = SyncSession(session)
@@ -72,26 +62,26 @@ class PushQueue(object):
             session=self.session.session,  # type: ignore[arg-type]
         )
 
-    def headers(self)                  :
+    def headers(self) -> Dict[str, str]:
         if self._api_is_dev:
             return {'Content-Type': 'application/json'}
 
         token = self.token.get()
         return {
-            'Authorization': 'Bearer {}'.format((token)),
+            'Authorization': f'Bearer {token}',
             'Content-Type': 'application/json',
         }
 
-    def task_name(self, task_id     )       :
-        return '{}/tasks/{}'.format((self._queue_path), (task_id))
+    def task_name(self, task_id: str) -> str:
+        return f'{self._queue_path}/tasks/{task_id}'
 
     # https://cloud.google.com/tasks/docs/reference/rest/v2beta3/projects.locations.queues.tasks/create
     def create(
-        self, task                ,
-        session                    = None,
-        timeout      = 10,
-    )       :
-        url = '{}/{}/tasks'.format((self._api_root), (self._queue_path))
+        self, task: Dict[str, Any],
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Any:
+        url = f'{self._api_root}/{self._queue_path}/tasks'
         payload = json.dumps({
             'task': task,
             'responseView': 'FULL',
@@ -106,11 +96,11 @@ class PushQueue(object):
 
     # https://cloud.google.com/tasks/docs/reference/rest/v2beta3/projects.locations.queues.tasks/delete
     def delete(
-        self, tname     ,
-        session                    = None,
-        timeout      = 10,
-    )       :
-        url = '{}/{}'.format((self._api_root), (tname))
+        self, tname: str,
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Any:
+        url = f'{self._api_root}/{tname}'
 
         headers = self.headers()
 
@@ -120,11 +110,11 @@ class PushQueue(object):
 
     # https://cloud.google.com/tasks/docs/reference/rest/v2beta3/projects.locations.queues.tasks/get
     def get(
-        self, tname     , full       = False,
-        session                    = None,
-        timeout      = 10,
-    )       :
-        url = '{}/{}'.format((self._api_root), (tname))
+        self, tname: str, full: bool = False,
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Any:
+        url = f'{self._api_root}/{tname}'
         params = {
             'responseView': 'FULL' if full else 'BASIC',
         }
@@ -138,13 +128,13 @@ class PushQueue(object):
 
     # https://cloud.google.com/tasks/docs/reference/rest/v2beta3/projects.locations.queues.tasks/list
     def list(
-        self, full       = False, page_size      = 1000,
-        page_token      = '',
-        session                    = None,
-        timeout      = 10,
-    )       :
-        url = '{}/{}/tasks'.format((self._api_root), (self._queue_path))
-        params                             = {
+        self, full: bool = False, page_size: int = 1000,
+        page_token: str = '',
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Any:
+        url = f'{self._api_root}/{self._queue_path}/tasks'
+        params: Dict[str, Union[int, str]] = {
             'responseView': 'FULL' if full else 'BASIC',
             'pageSize': page_size,
             'pageToken': page_token,
@@ -159,11 +149,11 @@ class PushQueue(object):
 
     # https://cloud.google.com/tasks/docs/reference/rest/v2beta3/projects.locations.queues.tasks/run
     def run(
-        self, tname     , full       = False,
-        session                    = None,
-        timeout      = 10,
-    )       :
-        url = '{}/{}:run'.format((self._api_root), (tname))
+        self, tname: str, full: bool = False,
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Any:
+        url = f'{self._api_root}/{tname}:run'
         payload = json.dumps({
             'responseView': 'FULL' if full else 'BASIC',
         }).encode('utf-8')
@@ -175,11 +165,11 @@ class PushQueue(object):
                             timeout=timeout)
         return resp.json()
 
-    def close(self)        :
+    def close(self) -> None:
         self.session.close()
 
-    def __enter__(self)               :
+    def __enter__(self) -> 'PushQueue':
         return self
 
-    def __exit__(self, *args     )        :
+    def __exit__(self, *args: Any) -> None:
         self.close()
